@@ -57,9 +57,7 @@ def module_contains_display(expression):
     contains_display_func = False
     for arg in expression.value.args:
         if isinstance(arg.parent, astroid.nodes.Call):
-            print(arg.parent.func)
-            print(arg.parent.func.name)
-            if arg.parent.func.name == "display":
+            if hasattr(arg.parent.func, "name") and arg.parent.func.name == "display":
                 contains_display_func = True
     return (
         contains_func_attribute and contains_attrname and contains_display_attr
@@ -76,7 +74,7 @@ def module_contains_show(expression):
     contains_show_func = False
     for arg in expression.value.args:
         if isinstance(arg.parent, astroid.nodes.Call):
-            if arg.parent.func.name == "show":
+            if hasattr(arg.parent.func, "name") and arg.parent.func.name == "show":
                 contains_show_func = True
     return (contains_func_attribute and contains_attrname and contains_show_attr) or (
         contains_func_attribute and contains_show_func
@@ -93,7 +91,7 @@ def module_contains_print(expression):
     contains_print_func = False
     for arg in expression.value.args:
         if isinstance(arg.parent, astroid.nodes.Call):
-            if arg.parent.func.name == "print":
+            if hasattr(arg.parent.func, "name") and arg.parent.func.name == "print":
                 contains_print_func = True
     return contains_func_attribute and contains_print_func
 
